@@ -12,6 +12,7 @@
 #include <QtGlobal>
 
 #if HAVE_X11
+#include <KWindowSystem>
 #include <KX11Extras>
 #endif
 
@@ -22,7 +23,7 @@ bool WindowSystemInfo::HAVE_TRANSPARENCY = false;
 bool WindowSystemInfo::compositingActive()
 {
 #if HAVE_X11
-    return KX11Extras::compositingActive();
+    return !KWindowSystem::isPlatformX11() || KX11Extras::compositingActive();
 #else
     return true;
 #endif
